@@ -4,7 +4,7 @@
 #
 # @author: Eric Lapouyade
 
-__version__ = '0.2.9'
+__version__ = '0.2.10'
 __author__ = 'Eric Lapouyade'
 __copyright__ = 'Copyright 2015, python-textops project'
 __credits__ = ['Eric Lapouyade']
@@ -27,6 +27,6 @@ logger.addHandler(NullHandler())
 from base import TextOp, WrapOp, WrapOpIter, WrapOpStr, add_textop, add_textop_iter, \
                  StrExt, UnicodeExt, ListExt, DictExt, NoAttrDict, NoAttr, DefaultList, \
                  DefaultDict, string_formatter, dictmerge, vformat, dformat, eformat, \
-                 stru, activate_debug, pp
+                 stru, activate_debug, pp, extend_type, extend_type_gen
 import ops
 from ops import *
